CradminSearchInput | django_cradmin API Document

    import CradminSearchInput from 'django_cradmin/scripts/django_cradmin/components/CradminSearchInput.jsx'

public class | source

# CradminSearchInput

#### Extends:

react~React.Component → CradminSearchInput

## Static Member Summary

Static Public Members
public static get | defaultProps: * |

## Constructor Summary

Public Constructor
public | constructor(props: *) |

## Member Summary

Public Members
public get | hotKeysHandlers: * |
public get | hotKeysMap: * |
public | logger: * |
public | state: * |

## Method Summary

Public Methods
public | componentWillUnmount() |
public | handleBlur() |
public | handleChange(event: *) |
public | handleFocus() |
public | initializeSignalHandlers() |
public | render(): * |
public | renderInputField(): * |

## Static Public Members

### public static get defaultProps: * source

## Public Constructors

### public constructor(props: *) source

#### Params:

Name | Type | Attribute | Description
props | * |  |

## Public Members

### public get hotKeysHandlers: * source

### public get hotKeysMap: * source

### public logger: * source

### public state: * source

## Public Methods

### public componentWillUnmount() source

### public handleBlur() source

### public handleChange(event: *) source

#### Params:

Name | Type | Attribute | Description
event | * |  |

### public handleFocus() source

### public initializeSignalHandlers() source

### public render(): * source

#### Return:

*

### public renderInputField(): * source

#### Return:

*